"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.timestamp_pb2
import prodvana.proto.prodvana.events.types_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class Event(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    DETAILS_FIELD_NUMBER: builtins.int
    TIMESTAMP_FIELD_NUMBER: builtins.int
    RELATED_OBJECTS_FIELD_NUMBER: builtins.int
    ACTOR_FIELD_NUMBER: builtins.int
    id: builtins.str
    type: prodvana.proto.prodvana.events.types_pb2.EventType.ValueType
    title: builtins.str
    @property
    def details(self) -> prodvana.proto.prodvana.events.types_pb2.EventDetails: ...
    @property
    def timestamp(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def related_objects(self) -> global___RelatedObjects: ...
    actor: builtins.str
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        type: prodvana.proto.prodvana.events.types_pb2.EventType.ValueType = ...,
        title: builtins.str = ...,
        details: prodvana.proto.prodvana.events.types_pb2.EventDetails | None = ...,
        timestamp: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        related_objects: global___RelatedObjects | None = ...,
        actor: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["details", b"details", "related_objects", b"related_objects", "timestamp", b"timestamp"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["actor", b"actor", "details", b"details", "id", b"id", "related_objects", b"related_objects", "timestamp", b"timestamp", "title", b"title", "type", b"type"]) -> None: ...

global___Event = Event

class RelatedObjects(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class ExternalLogsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    APPLICATION_ID_FIELD_NUMBER: builtins.int
    SERVICE_ID_FIELD_NUMBER: builtins.int
    RELEASE_CHANNEL_ID_FIELD_NUMBER: builtins.int
    DESIRED_STATE_ID_FIELD_NUMBER: builtins.int
    ROOT_DESIRED_STATE_ID_FIELD_NUMBER: builtins.int
    RELEASE_ID_FIELD_NUMBER: builtins.int
    RUNTIME_ID_FIELD_NUMBER: builtins.int
    EXTERNAL_LOGS_FIELD_NUMBER: builtins.int
    application_id: builtins.str
    service_id: builtins.str
    release_channel_id: builtins.str
    desired_state_id: builtins.str
    root_desired_state_id: builtins.str
    release_id: builtins.str
    runtime_id: builtins.str
    @property
    def external_logs(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """next tag: 9"""
    def __init__(
        self,
        *,
        application_id: builtins.str = ...,
        service_id: builtins.str = ...,
        release_channel_id: builtins.str = ...,
        desired_state_id: builtins.str = ...,
        root_desired_state_id: builtins.str = ...,
        release_id: builtins.str = ...,
        runtime_id: builtins.str = ...,
        external_logs: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["application_id", b"application_id", "desired_state_id", b"desired_state_id", "external_logs", b"external_logs", "release_channel_id", b"release_channel_id", "release_id", b"release_id", "root_desired_state_id", b"root_desired_state_id", "runtime_id", b"runtime_id", "service_id", b"service_id"]) -> None: ...

global___RelatedObjects = RelatedObjects



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _Role:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _RoleEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_Role.ValueType], builtins.type):  # noqa: F821
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    UNSPECIFIED: _Role.ValueType  # 0
    ORG_ADMIN: _Role.ValueType  # 1
    CLOUD_ADMIN: _Role.ValueType  # 2
    SERVICE_OWNER: _Role.ValueType  # 3
    VIEWER: _Role.ValueType  # 4

class Role(_Role, metaclass=_RoleEnumTypeWrapper): ...

UNSPECIFIED: Role.ValueType  # 0
ORG_ADMIN: Role.ValueType  # 1
CLOUD_ADMIN: Role.ValueType  # 2
SERVICE_OWNER: Role.ValueType  # 3
VIEWER: Role.ValueType  # 4
global___Role = Role



import mock

from prodvana.client import Client
from prodvana.proto.prodvana.common_config import parameters_pb2, program_pb2
from prodvana.proto.prodvana.desired_state import manager_pb2
from prodvana.proto.prodvana.desired_state.model import desired_state_pb2
from prodvana.proto.prodvana.service import (
    service_config_pb2,
    service_manager_pb2,
    service_manager_pb2_grpc,
)
from prodvana.utils.service_config import get_target_image_tags_for_desired_state


def test_get_target_commits_with_image_urls() -> None:
    def fake_get_service_config(
        req: service_manager_pb2.GetMaterializedConfigReq,
    ) -> service_manager_pb2.GetMaterializedConfigResp:
        return service_manager_pb2.GetMaterializedConfigResp(
            compiled_service_instance_configs=[
                service_config_pb2.CompiledServiceInstanceConfig(
                    parameter_values=[
                        parameters_pb2.ParameterValue(
                            docker_image_tag={
                                "pvn-service-1": "1",
                                "pvn-service-2": "2",
                            }[req.version],
                        ),
                    ],
                    parameters=[
                        parameters_pb2.ParameterDefinition(
                            docker_image=parameters_pb2.DockerImageParameterDefinition(
                                default_tag="foo",
                                image_registry_info=program_pb2.ImageRegistryInfo(
                                    container_registry="registry",
                                    image_repository="repo",
                                ),
                            ),
                        ),
                    ],
                ),
            ]
        )

    client = mock.Mock(spec=Client)
    client.service_manager = mock.Mock(spec=service_manager_pb2_grpc.ServiceManagerStub)
    client.service_manager.GetMaterializedConfig = mock.Mock()
    client.service_manager.GetMaterializedConfig.side_effect = fake_get_service_config

    images = get_target_image_tags_for_desired_state(
        client,
        manager_pb2.DesiredStateSummary(
            desired_state=desired_state_pb2.State(
                service=desired_state_pb2.ServiceState(
                    release_channels=[
                        desired_state_pb2.ServiceInstanceState(
                            versions=[
                                desired_state_pb2.Version(
                                    version="pvn-service-1",
                                ),
                            ],
                        ),
                    ],
                ),
            ),
        ),
    )
    assert images == set(["1"])

    images = get_target_image_tags_for_desired_state(
        client,
        manager_pb2.DesiredStateSummary(
            desired_state=desired_state_pb2.State(
                service=desired_state_pb2.ServiceState(
                    release_channels=[
                        desired_state_pb2.ServiceInstanceState(
                            release_channel="staging",
                            versions=[
                                desired_state_pb2.Version(
                                    version="pvn-service-2",
                                ),
                            ],
                        ),
                        desired_state_pb2.ServiceInstanceState(
                            release_channel="production",
                            versions=[
                                desired_state_pb2.Version(
                                    version="pvn-service-1",
                                ),
                            ],
                        ),
                    ],
                ),
            ),
        ),
    )
    assert images == set(
        [
            "2",
            "1",
        ]
    )



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/object/manager.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from prodvana.proto.prodvana.labels import labels_pb2 as prodvana_dot_labels_dot_labels__pb2
from prodvana.proto.prodvana.object import meta_pb2 as prodvana_dot_object_dot_meta__pb2
from prodvana.proto.validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1dprodvana/object/manager.proto\x12\x0fprodvana.object\x1a\x1cgoogle/api/annotations.proto\x1a\x1cprodvana/labels/labels.proto\x1a\x1aprodvana/object/meta.proto\x1a\x17validate/validate.proto\"(\n\x0eQueryObjectReq\x12\x16\n\x05query\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\"?\n\x0fQueryObjectResp\x12,\n\x07objects\x18\x01 \x03(\x0b\x32\x1b.prodvana.object.ObjectMeta\"E\n\x0cGetLabelsReq\x12)\n\x04type\x18\x01 \x01(\x0e\x32\x1b.prodvana.object.ObjectType\x12\n\n\x02id\x18\x02 \x01(\t\"M\n\rGetLabelsResp\x12\x30\n\x06labels\x18\x02 \x03(\x0b\x32 .prodvana.labels.LabelDefinitionJ\x04\x08\x01\x10\x02R\x04meta2\xe5\x01\n\rObjectManager\x12l\n\x0cQueryObjects\x12\x1f.prodvana.object.QueryObjectReq\x1a .prodvana.object.QueryObjectResp\"\x19\x82\xd3\xe4\x93\x02\x13\x12\x11/v1/objects/query\x12\x66\n\tGetLabels\x12\x1d.prodvana.object.GetLabelsReq\x1a\x1e.prodvana.object.GetLabelsResp\"\x1a\x82\xd3\xe4\x93\x02\x14\x12\x12/v1/objects/labelsBKZIgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/objectb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'prodvana.object.manager_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZIgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/object'
  _QUERYOBJECTREQ.fields_by_name['query']._options = None
  _QUERYOBJECTREQ.fields_by_name['query']._serialized_options = b'\372B\004r\002\020\001'
  _OBJECTMANAGER.methods_by_name['QueryObjects']._options = None
  _OBJECTMANAGER.methods_by_name['QueryObjects']._serialized_options = b'\202\323\344\223\002\023\022\021/v1/objects/query'
  _OBJECTMANAGER.methods_by_name['GetLabels']._options = None
  _OBJECTMANAGER.methods_by_name['GetLabels']._serialized_options = b'\202\323\344\223\002\024\022\022/v1/objects/labels'
  _globals['_QUERYOBJECTREQ']._serialized_start=163
  _globals['_QUERYOBJECTREQ']._serialized_end=203
  _globals['_QUERYOBJECTRESP']._serialized_start=205
  _globals['_QUERYOBJECTRESP']._serialized_end=268
  _globals['_GETLABELSREQ']._serialized_start=270
  _globals['_GETLABELSREQ']._serialized_end=339
  _globals['_GETLABELSRESP']._serialized_start=341
  _globals['_GETLABELSRESP']._serialized_end=418
  _globals['_OBJECTMANAGER']._serialized_start=421
  _globals['_OBJECTMANAGER']._serialized_end=650
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/desired_state/manager.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from prodvana.proto.prodvana.async_task import task_metadata_pb2 as prodvana_dot_async__task_dot_task__metadata__pb2
from prodvana.proto.prodvana.desired_state.debug import debug_pb2 as prodvana_dot_desired__state_dot_debug_dot_debug__pb2
from prodvana.proto.prodvana.desired_state.maestro import maestro_pb2 as prodvana_dot_desired__state_dot_maestro_dot_maestro__pb2
from prodvana.proto.prodvana.desired_state.model import desired_state_pb2 as prodvana_dot_desired__state_dot_model_dot_desired__state__pb2
from prodvana.proto.prodvana.desired_state.model import entity_pb2 as prodvana_dot_desired__state_dot_model_dot_entity__pb2
from prodvana.proto.prodvana.service import service_config_pb2 as prodvana_dot_service_dot_service__config__pb2
from prodvana.proto.prodvana.version import source_metadata_pb2 as prodvana_dot_version_dot_source__metadata__pb2
from prodvana.proto.validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$prodvana/desired_state/manager.proto\x12\x16prodvana.desired_state\x1a\x1cgoogle/api/annotations.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\'prodvana/async_task/task_metadata.proto\x1a(prodvana/desired_state/debug/debug.proto\x1a,prodvana/desired_state/maestro/maestro.proto\x1a\x30prodvana/desired_state/model/desired_state.proto\x1a)prodvana/desired_state/model/entity.proto\x1a%prodvana/service/service_config.proto\x1a&prodvana/version/source_metadata.proto\x1a\x17validate/validate.proto\"\xf6\x02\n\x12SetDesiredStateReq\x12\x44\n\rdesired_state\x18\x01 \x01(\x0b\x32#.prodvana.desired_state.model.StateB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12\x10\n\x08rollback\x18\x02 \x01(\x08\x12,\n$bypass_preconditions_and_protections\x18\x06 \x01(\x08\x12(\n\x06source\x18\x03 \x01(\x0e\x32\x18.prodvana.version.Source\x12\x39\n\x0fsource_metadata\x18\x04 \x01(\x0b\x32 .prodvana.version.SourceMetadata\x12%\n\x1d\x66orce_async_set_desired_state\x18\x05 \x01(\x08\x12N\n\x17maestro_config_override\x18\x07 \x01(\x0b\x32-.prodvana.desired_state.maestro.MaestroConfig\"\xb4\x02\n\x17ValidateDesiredStateReq\x12\x44\n\rdesired_state\x18\x01 \x01(\x0b\x32#.prodvana.desired_state.model.StateB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12\x10\n\x08rollback\x18\x02 \x01(\x08\x12,\n$bypass_preconditions_and_protections\x18\x06 \x01(\x08\x12Q\n\x18service_instance_configs\x18\x03 \x03(\x0b\x32/.prodvana.service.CompiledServiceInstanceConfig\x12\x1c\n\x14label_expansion_only\x18\x04 \x01(\x08\x12\"\n\x1a\x64isregard_service_versions\x18\x05 \x01(\x08\"S\n\x13SetDesiredStateResp\x12\x1a\n\x10\x64\x65sired_state_id\x18\x01 \x01(\tH\x00\x12\x14\n\nrelease_id\x18\x02 \x01(\tH\x00\x42\n\n\x08id_oneof\"s\n\x16PreviewEntityGraphResp\x12?\n\x0c\x65ntity_graph\x18\x01 \x01(\x0b\x32).prodvana.desired_state.model.EntityGraph\x12\x18\n\x10\x64\x65sired_state_id\x18\x02 \x01(\t\"\x88\x01\n+GetServiceDesiredStateConvergenceSummaryReq\x12\x1c\n\x0b\x61pplication\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x18\n\x07service\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12!\n\x19\x66\x61st_no_deprecated_fields\x18\x03 \x01(\x08\"b\n\x12StatusExplanations\x12L\n\x13status_explanations\x18\x01 \x03(\x0b\x32/.prodvana.desired_state.model.StatusExplanation\"G\n\tDebugLogs\x12:\n\ndebug_logs\x18\x01 \x03(\x0b\x32&.prodvana.desired_state.model.DebugLog\"\xe3\x01\n\x16PendingSetDesiredState\x12\x18\n\x10\x64\x65sired_state_id\x18\x04 \x01(\t\x12\x43\n\x16\x63ompiled_desired_state\x18\x01 \x01(\x0b\x32#.prodvana.desired_state.model.State\x12\x34\n\x0btask_status\x18\x02 \x01(\x0e\x32\x1f.prodvana.async_task.TaskStatus\x12\x34\n\x0btask_result\x18\x03 \x01(\x0b\x32\x1f.prodvana.async_task.TaskResult\"\xba\x12\n\x13\x44\x65siredStateSummary\x12?\n\x0c\x65ntity_graph\x18\x0f \x01(\x0b\x32).prodvana.desired_state.model.EntityGraph\x12\x36\n\x12\x63reation_timestamp\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x39\n\x15last_update_timestamp\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x36\n\x12replaced_timestamp\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12@\n\x13input_desired_state\x18\x10 \x01(\x0b\x32#.prodvana.desired_state.model.State\x12:\n\rdesired_state\x18\x03 \x01(\x0b\x32#.prodvana.desired_state.model.State\x12;\n\x0estarting_state\x18\x01 \x01(\x0b\x32#.prodvana.desired_state.model.State\x12<\n\x0flast_seen_state\x18\x02 \x01(\x0b\x32#.prodvana.desired_state.model.State\x12\x34\n\x06status\x18\x13 \x01(\x0e\x32$.prodvana.desired_state.model.Status\x12(\n\x06source\x18\x11 \x01(\x0e\x32\x18.prodvana.version.Source\x12\x39\n\x0fsource_metadata\x18\x12 \x01(\x0b\x32 .prodvana.version.SourceMetadata\x12Q\n\x19pending_set_desired_state\x18\x14 \x01(\x0b\x32..prodvana.desired_state.PendingSetDesiredState\x12Y\n\x1aset_desired_state_metadata\x18\x15 \x01(\x0b\x32\x35.prodvana.desired_state.model.SetDesiredStateMetadata\x12K\n\x08statuses\x18\x04 \x03(\x0b\x32\x39.prodvana.desired_state.DesiredStateSummary.StatusesEntry\x12\x64\n\x15precondition_statuses\x18\x08 \x03(\x0b\x32\x45.prodvana.desired_state.DesiredStateSummary.PreconditionStatusesEntry\x12`\n\x13status_explanations\x18\t \x03(\x0b\x32\x43.prodvana.desired_state.DesiredStateSummary.StatusExplanationsEntry\x12N\n\ndebug_logs\x18\n \x03(\x0b\x32:.prodvana.desired_state.DesiredStateSummary.DebugLogsEntry\x12`\n\x13\x61\x63tion_explanations\x18\x0b \x03(\x0b\x32\x43.prodvana.desired_state.DesiredStateSummary.ActionExplanationsEntry\x12\x65\n\x16last_update_timestamps\x18\x0c \x03(\x0b\x32\x45.prodvana.desired_state.DesiredStateSummary.LastUpdateTimestampsEntry\x12g\n\x17last_fetched_timestamps\x18\r \x03(\x0b\x32\x46.prodvana.desired_state.DesiredStateSummary.LastFetchedTimestampsEntry\x12g\n\x17last_applied_timestamps\x18\x0e \x03(\x0b\x32\x46.prodvana.desired_state.DesiredStateSummary.LastAppliedTimestampsEntry\x1aU\n\rStatusesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x33\n\x05value\x18\x02 \x01(\x0e\x32$.prodvana.desired_state.model.Status:\x02\x38\x01\x1ai\n\x19PreconditionStatusesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12;\n\x05value\x18\x02 \x01(\x0b\x32,.prodvana.desired_state.model.ConditionState:\x02\x38\x01\x1a\x65\n\x17StatusExplanationsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x39\n\x05value\x18\x02 \x01(\x0b\x32*.prodvana.desired_state.StatusExplanations:\x02\x38\x01\x1aS\n\x0e\x44\x65\x62ugLogsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x30\n\x05value\x18\x02 \x01(\x0b\x32!.prodvana.desired_state.DebugLogs:\x02\x38\x01\x1aj\n\x17\x41\x63tionExplanationsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12>\n\x05value\x18\x02 \x01(\x0b\x32/.prodvana.desired_state.model.ActionExplanation:\x02\x38\x01\x1aW\n\x19LastUpdateTimestampsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12)\n\x05value\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp:\x02\x38\x01\x1aX\n\x1aLastFetchedTimestampsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12)\n\x05value\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp:\x02\x38\x01\x1aX\n\x1aLastAppliedTimestampsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12)\n\x05value\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp:\x02\x38\x01\"e\n\x1dGetDesiredStateConvergenceReq\x12!\n\x10\x64\x65sired_state_id\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12!\n\x19\x66\x61st_no_deprecated_fields\x18\x02 \x01(\x08\"e\n%GetDesiredStateConvergenceSummaryResp\x12<\n\x07summary\x18\x01 \x01(\x0b\x32+.prodvana.desired_state.DesiredStateSummary\"l\n,GetServiceDesiredStateConvergenceSummaryResp\x12<\n\x07summary\x18\x01 \x01(\x0b\x32+.prodvana.desired_state.DesiredStateSummary\"Y\n\x1fGetServiceLastConvergedStateReq\x12\x1c\n\x0b\x61pplication\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x18\n\x07service\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\"w\n GetServiceLastConvergedStateResp\x12S\n\x17service_instance_states\x18\x01 \x03(\x0b\x32\x32.prodvana.desired_state.model.ServiceInstanceState\"\xa4\x01\n GetServiceDesiredStateHistoryReq\x12\x1c\n\x0b\x61pplication\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x18\n\x07service\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x12\n\npage_token\x18\x03 \x01(\t\x12\x11\n\tpage_size\x18\x04 \x01(\x05\x12!\n\x19\x66\x61st_no_deprecated_fields\x18\x05 \x01(\x08\"\x81\x01\n!GetServiceDesiredStateHistoryResp\x12\x43\n\x0e\x64\x65sired_states\x18\x01 \x03(\x0b\x32+.prodvana.desired_state.DesiredStateSummary\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"7\n\x12GetDesiredStateReq\x12!\n\x10\x64\x65sired_state_id\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\"\x8e\x03\n\x13GetDesiredStateResp\x12:\n\rdesired_state\x18\x01 \x01(\x0b\x32#.prodvana.desired_state.model.State\x12\x43\n\x16\x63ompiled_desired_state\x18\x02 \x01(\x0b\x32#.prodvana.desired_state.model.State\x12Y\n\x1aset_desired_state_metadata\x18\x03 \x01(\x0b\x32\x35.prodvana.desired_state.model.SetDesiredStateMetadata\x12\x36\n\x12\x63reation_timestamp\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12(\n\x06source\x18\x05 \x01(\x0e\x32\x18.prodvana.version.Source\x12\x39\n\x0fsource_metadata\x18\x06 \x01(\x0b\x32 .prodvana.version.SourceMetadata\"\x95\x05\n\x17GetDesiredStateGraphReq\x12#\n\x10\x64\x65sired_state_id\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01H\x00\x12Z\n\x10query_by_service\x18\x06 \x01(\x0b\x32>.prodvana.desired_state.GetDesiredStateGraphReq.QueryByServiceH\x00\x12\x31\n\x05types\x18\x07 \x03(\x0e\x32\".prodvana.desired_state.model.Type\x12G\n\x14required_annotations\x18\x03 \x01(\x0b\x32).prodvana.desired_state.model.Annotations\x12\x1d\n\x15required_entity_names\x18\t \x03(\t\x12\r\n\x05\x64\x65pth\x18\x04 \x01(\x05\x12h\n\x19\x64\x65pth_overrides_by_status\x18\x08 \x03(\x0b\x32\x45.prodvana.desired_state.GetDesiredStateGraphReq.DepthOverrideByStatus\x12(\n include_desired_state_timestamps\x18\x05 \x01(\x08\x1aH\n\x0eQueryByService\x12\x1c\n\x0b\x61pplication\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x18\n\x07service\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x1a\\\n\x15\x44\x65pthOverrideByStatus\x12\x34\n\x06status\x18\x01 \x01(\x0e\x32$.prodvana.desired_state.model.Status\x12\r\n\x05\x64\x65pth\x18\x02 \x01(\x05\x42\x07\n\x05queryJ\x04\x08\x02\x10\x03R\x04type\"\xc3\x01\n\x16\x44\x65siredStateTimestamps\x12\x36\n\x12\x63reation_timestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x39\n\x15last_update_timestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x36\n\x12replaced_timestamp\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\xf2\x01\n\x18GetDesiredStateGraphResp\x12?\n\x0c\x65ntity_graph\x18\x01 \x01(\x0b\x32).prodvana.desired_state.model.EntityGraph\x12Q\n\x19pending_set_desired_state\x18\x02 \x01(\x0b\x32..prodvana.desired_state.PendingSetDesiredState\x12\x42\n\ntimestamps\x18\x03 \x01(\x0b\x32..prodvana.desired_state.DesiredStateTimestamps\"[\n!GetServiceLatestDesiredStateIdReq\x12\x1c\n\x0b\x61pplication\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x18\n\x07service\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\"\x91\x01\n\"GetServiceLatestDesiredStateIdResp\x12\x18\n\x10\x64\x65sired_state_id\x18\x01 \x01(\t\x12Q\n\x19pending_set_desired_state\x18\x02 \x01(\x0b\x32..prodvana.desired_state.PendingSetDesiredState\"\x83\x01\n\"GetServiceDesiredStateIdHistoryReq\x12\x1c\n\x0b\x61pplication\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x18\n\x07service\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x12\n\npage_token\x18\x03 \x01(\t\x12\x11\n\tpage_size\x18\x04 \x01(\x05\"Y\n#GetServiceDesiredStateIdHistoryResp\x12\x19\n\x11\x64\x65sired_state_ids\x18\x01 \x03(\t\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x9b\x01\n\x18ValidateDesiredStateResp\x12:\n\rdesired_state\x18\x01 \x01(\x0b\x32#.prodvana.desired_state.model.State\x12\x43\n\x16\x63ompiled_desired_state\x18\x02 \x01(\x0b\x32#.prodvana.desired_state.model.State\"|\n\x14SetManualApprovalReq\x12!\n\x10\x64\x65sired_state_id\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x16\n\x05topic\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x0e\n\x06reject\x18\x03 \x01(\x08\x12\x13\n\x0bsignal_type\x18\x05 \x01(\tJ\x04\x08\x04\x10\x05\"\x17\n\x15SetManualApprovalResp\"}\n\x12PromoteDeliveryReq\x12!\n\x10\x64\x65sired_state_id\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\r\n\x05stage\x18\x02 \x01(\x03\x12\x0c\n\x04\x66ull\x18\x03 \x01(\x08\x12\x0e\n\x06reject\x18\x05 \x01(\x08\x12\x17\n\x06source\x18\x04 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\"\x15\n\x13PromoteDeliveryResp\"Q\n\x13\x42ypassProtectionReq\x12!\n\x10\x64\x65sired_state_id\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x17\n\x06source\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\"\x16\n\x14\x42ypassProtectionResp\"\xb7\x01\n\x16ListMaestroReleasesReq\x12\x45\n\tentity_id\x18\x01 \x01(\x0b\x32(.prodvana.desired_state.model.IdentifierB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12\x12\n\ndescending\x18\x05 \x01(\x08\x12\x1b\n\x13starting_release_id\x18\x02 \x01(\t\x12\x12\n\npage_token\x18\x03 \x01(\t\x12\x11\n\tpage_size\x18\x04 \x01(\x05\"|\n\x17ListMaestroReleasesResp\x12H\n\x10maestro_releases\x18\x01 \x03(\x0b\x32..prodvana.desired_state.maestro.MaestroRelease\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"3\n\x14GetMaestroReleaseReq\x12\x1b\n\nrelease_id\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\"`\n\x15GetMaestroReleaseResp\x12G\n\x0fmaestro_release\x18\x01 \x01(\x0b\x32..prodvana.desired_state.maestro.MaestroRelease\"\x9b\x01\n\x17ListCombinedReleasesReq\x12\x45\n\tentity_id\x18\x01 \x01(\x0b\x32(.prodvana.desired_state.model.IdentifierB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12\x12\n\ndescending\x18\x04 \x01(\x08\x12\x12\n\npage_token\x18\x02 \x01(\t\x12\x11\n\tpage_size\x18\x03 \x01(\x05\"\x93\x01\n\x1eListServiceCombinedReleasesReq\x12\x1c\n\x0b\x61pplication\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x18\n\x07service\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x12\n\ndescending\x18\x03 \x01(\x08\x12\x12\n\npage_token\x18\x04 \x01(\t\x12\x11\n\tpage_size\x18\x05 \x01(\x05\"\x86\x02\n\x18ListCombinedReleasesResp\x12J\n\x08releases\x18\x01 \x03(\x0b\x32\x38.prodvana.desired_state.ListCombinedReleasesResp.Release\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\x1a\x84\x01\n\x07Release\x12\x1a\n\x10\x64\x65sired_state_id\x18\x01 \x01(\tH\x00\x12\x14\n\nrelease_id\x18\x02 \x01(\tH\x00\x12\x36\n\x12\x63reation_timestamp\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x0f\n\rrelease_oneof\"p\n\'GetLatestCombinedReleaseDesiredStateReq\x12\x45\n\tentity_id\x18\x01 \x01(\x0b\x32(.prodvana.desired_state.model.IdentifierB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\"h\n.GetServiceLatestCombinedReleaseDesiredStateReq\x12\x1c\n\x0b\x61pplication\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x18\n\x07service\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\"\xa9\x03\n(GetLatestCombinedReleaseDesiredStateResp\x12@\n\x13input_desired_state\x18\x01 \x01(\x0b\x32#.prodvana.desired_state.model.State\x12\x43\n\x16\x63ompiled_desired_state\x18\x02 \x01(\x0b\x32#.prodvana.desired_state.model.State\x12Y\n\x1aset_desired_state_metadata\x18\x03 \x01(\x0b\x32\x35.prodvana.desired_state.model.SetDesiredStateMetadata\x12\x36\n\x12\x63reation_timestamp\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12(\n\x06source\x18\x05 \x01(\x0e\x32\x18.prodvana.version.Source\x12\x39\n\x0fsource_metadata\x18\x06 \x01(\x0b\x32 .prodvana.version.SourceMetadata2\x9d \n\x13\x44\x65siredStateManager\x12\x89\x01\n\x0fSetDesiredState\x12*.prodvana.desired_state.SetDesiredStateReq\x1a+.prodvana.desired_state.SetDesiredStateResp\"\x1d\x82\xd3\xe4\x93\x02\x17\"\x12/v1/desired_states:\x01*\x12\x97\x01\n\x12PreviewEntityGraph\x12*.prodvana.desired_state.SetDesiredStateReq\x1a..prodvana.desired_state.PreviewEntityGraphResp\"%\x82\xd3\xe4\x93\x02\x1f\"\x1a/v1/desired_states/preview:\x01*\x12\x89\x02\n(GetServiceDesiredStateConvergenceSummary\x12\x43.prodvana.desired_state.GetServiceDesiredStateConvergenceSummaryReq\x1a\x44.prodvana.desired_state.GetServiceDesiredStateConvergenceSummaryResp\"R\x82\xd3\xe4\x93\x02L\x12J/v1/applications/{application=*}/services/{service=*}/latest_desired_state\x12\xee\x01\n\x1eGetServiceLatestDesiredStateId\x12\x39.prodvana.desired_state.GetServiceLatestDesiredStateIdReq\x1a:.prodvana.desired_state.GetServiceLatestDesiredStateIdResp\"U\x82\xd3\xe4\x93\x02O\x12M/v1/applications/{application=*}/services/{service=*}/latest_desired_state_id\x12\xf2\x01\n\x1fGetServiceDesiredStateIdHistory\x12:.prodvana.desired_state.GetServiceDesiredStateIdHistoryReq\x1a;.prodvana.desired_state.GetServiceDesiredStateIdHistoryResp\"V\x82\xd3\xe4\x93\x02P\x12N/v1/applications/{application=*}/services/{service=*}/desired_state_id_history\x12\xe0\x01\n\x1dGetServiceLastConvergedStates\x12\x37.prodvana.desired_state.GetServiceLastConvergedStateReq\x1a\x38.prodvana.desired_state.GetServiceLastConvergedStateResp\"L\x82\xd3\xe4\x93\x02\x46\x12\x44/v1/applications/{application=*}/services/{service=*}/last_converged\x12\xe2\x01\n\x1dGetServiceDesiredStateHistory\x12\x38.prodvana.desired_state.GetServiceDesiredStateHistoryReq\x1a\x39.prodvana.desired_state.GetServiceDesiredStateHistoryResp\"L\x82\xd3\xe4\x93\x02\x46\x12\x44/v1/applications/{application=*}/services/{service=*}/desired_states\x12\x9b\x01\n\x0fGetDesiredState\x12*.prodvana.desired_state.GetDesiredStateReq\x1a+.prodvana.desired_state.GetDesiredStateResp\"/\x82\xd3\xe4\x93\x02)\x12\'/v1/desired_states/{desired_state_id=*}\x12\x9e\x01\n\x14GetDesiredStateGraph\x12/.prodvana.desired_state.GetDesiredStateGraphReq\x1a\x30.prodvana.desired_state.GetDesiredStateGraphResp\"#\x82\xd3\xe4\x93\x02\x1d\"\x18/v1/desired_states/graph:\x01*\x12\xd2\x01\n!GetDesiredStateConvergenceSummary\x12\x35.prodvana.desired_state.GetDesiredStateConvergenceReq\x1a=.prodvana.desired_state.GetDesiredStateConvergenceSummaryResp\"7\x82\xd3\xe4\x93\x02\x31\x12//v1/desired_states/{desired_state_id=*}/summary\x12\xa1\x01\n\x14ValidateDesiredState\x12/.prodvana.desired_state.ValidateDesiredStateReq\x1a\x30.prodvana.desired_state.ValidateDesiredStateResp\"&\x82\xd3\xe4\x93\x02 \"\x1b/v1/desired_states/validate:\x01*\x12\xa8\x01\n\x11SetManualApproval\x12,.prodvana.desired_state.SetManualApprovalReq\x1a-.prodvana.desired_state.SetManualApprovalResp\"6\x82\xd3\xe4\x93\x02\x30\"+/v1/desired_states/approve_manual_condition:\x01*\x12\x9a\x01\n\x0fPromoteDelivery\x12*.prodvana.desired_state.PromoteDeliveryReq\x1a+.prodvana.desired_state.PromoteDeliveryResp\".\x82\xd3\xe4\x93\x02(\"#/v1/desired_states/promote_delivery:\x01*\x12\x9e\x01\n\x10\x42ypassProtection\x12+.prodvana.desired_state.BypassProtectionReq\x1a,.prodvana.desired_state.BypassProtectionResp\"/\x82\xd3\xe4\x93\x02)\"$/v1/desired_states/bypass_protection:\x01*\x12\xa3\x01\n\x13ListMaestroReleases\x12..prodvana.desired_state.ListMaestroReleasesReq\x1a/.prodvana.desired_state.ListMaestroReleasesResp\"+\x82\xd3\xe4\x93\x02%\x12#/v1/desired_states/maestro_releases\x12\xac\x01\n\x11GetMaestroRelease\x12,.prodvana.desired_state.GetMaestroReleaseReq\x1a-.prodvana.desired_state.GetMaestroReleaseResp\":\x82\xd3\xe4\x93\x02\x34\x12\x32/v1/desired_states/maestro_releases/{release_id=*}\x12\xa7\x01\n\x14ListCombinedReleases\x12/.prodvana.desired_state.ListCombinedReleasesReq\x1a\x30.prodvana.desired_state.ListCombinedReleasesResp\",\x82\xd3\xe4\x93\x02&\x12$/v1/desired_states/combined_releases\x12\xd8\x01\n\x1bListServiceCombinedReleases\x12\x36.prodvana.desired_state.ListServiceCombinedReleasesReq\x1a\x30.prodvana.desired_state.ListCombinedReleasesResp\"O\x82\xd3\xe4\x93\x02I\x12G/v1/applications/{application=*}/services/{service=*}/combined_releases\x12\xec\x01\n$GetLatestCombinedReleaseDesiredState\x12?.prodvana.desired_state.GetLatestCombinedReleaseDesiredStateReq\x1a@.prodvana.desired_state.GetLatestCombinedReleaseDesiredStateResp\"A\x82\xd3\xe4\x93\x02;\x12\x39/v1/desired_states/combined_releases/latest_desired_state\x12\x9d\x02\n+GetServiceLatestCombinedReleaseDesiredState\x12\x46.prodvana.desired_state.GetServiceLatestCombinedReleaseDesiredStateReq\x1a@.prodvana.desired_state.GetLatestCombinedReleaseDesiredStateResp\"d\x82\xd3\xe4\x93\x02^\x12\\/v1/applications/{application=*}/services/{service=*}/combined_releases/latest_desired_state\x12\x9b\x01\n\rGetDebugState\x12*.prodvana.desired_state.GetDesiredStateReq\x1a\'.prodvana.desired_state.debug.DumpState\"5\x82\xd3\xe4\x93\x02/\x12-/v1/desired_states/{desired_state_id=*}/debugBRZPgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/desired_stateb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'prodvana.desired_state.manager_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZPgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/desired_state'
  _SETDESIREDSTATEREQ.fields_by_name['desired_state']._options = None
  _SETDESIREDSTATEREQ.fields_by_name['desired_state']._serialized_options = b'\372B\005\212\001\002\020\001'
  _VALIDATEDESIREDSTATEREQ.fields_by_name['desired_state']._options = None
  _VALIDATEDESIREDSTATEREQ.fields_by_name['desired_state']._serialized_options = b'\372B\005\212\001\002\020\001'
  _GETSERVICEDESIREDSTATECONVERGENCESUMMARYREQ.fields_by_name['application']._options = None
  _GETSERVICEDESIREDSTATECONVERGENCESUMMARYREQ.fields_by_name['application']._serialized_options = b'\372B\004r\002\020\001'
  _GETSERVICEDESIREDSTATECONVERGENCESUMMARYREQ.fields_by_name['service']._options = None
  _GETSERVICEDESIREDSTATECONVERGENCESUMMARYREQ.fields_by_name['service']._serialized_options = b'\372B\004r\002\020\001'
  _DESIREDSTATESUMMARY_STATUSESENTRY._options = None
  _DESIREDSTATESUMMARY_STATUSESENTRY._serialized_options = b'8\001'
  _DESIREDSTATESUMMARY_PRECONDITIONSTATUSESENTRY._options = None
  _DESIREDSTATESUMMARY_PRECONDITIONSTATUSESENTRY._serialized_options = b'8\001'
  _DESIREDSTATESUMMARY_STATUSEXPLANATIONSENTRY._options = None
  _DESIREDSTATESUMMARY_STATUSEXPLANATIONSENTRY._serialized_options = b'8\001'
  _DESIREDSTATESUMMARY_DEBUGLOGSENTRY._options = None
  _DESIREDSTATESUMMARY_DEBUGLOGSENTRY._serialized_options = b'8\001'
  _DESIREDSTATESUMMARY_ACTIONEXPLANATIONSENTRY._options = None
  _DESIREDSTATESUMMARY_ACTIONEXPLANATIONSENTRY._serialized_options = b'8\001'
  _DESIREDSTATESUMMARY_LASTUPDATETIMESTAMPSENTRY._options = None
  _DESIREDSTATESUMMARY_LASTUPDATETIMESTAMPSENTRY._serialized_options = b'8\001'
  _DESIREDSTATESUMMARY_LASTFETCHEDTIMESTAMPSENTRY._options = None
  _DESIREDSTATESUMMARY_LASTFETCHEDTIMESTAMPSENTRY._serialized_options = b'8\001'
  _DESIREDSTATESUMMARY_LASTAPPLIEDTIMESTAMPSENTRY._options = None
  _DESIREDSTATESUMMARY_LASTAPPLIEDTIMESTAMPSENTRY._serialized_options = b'8\001'
  _GETDESIREDSTATECONVERGENCEREQ.fields_by_name['desired_state_id']._options = None
  _GETDESIREDSTATECONVERGENCEREQ.fields_by_name['desired_state_id']._serialized_options = b'\372B\004r\002\020\001'
  _GETSERVICELASTCONVERGEDSTATEREQ.fields_by_name['application']._options = None
  _GETSERVICELASTCONVERGEDSTATEREQ.fields_by_name['application']._serialized_options = b'\372B\004r\002\020\001'
  _GETSERVICELASTCONVERGEDSTATEREQ.fields_by_name['service']._options = None
  _GETSERVICELASTCONVERGEDSTATEREQ.fields_by_name['service']._serialized_options = b'\372B\004r\002\020\001'
  _GETSERVICEDESIREDSTATEHISTORYREQ.fields_by_name['application']._options = None
  _GETSERVICEDESIREDSTATEHISTORYREQ.fields_by_name['application']._serialized_options = b'\372B\004r\002\020\001'
  _GETSERVICEDESIREDSTATEHISTORYREQ.fields_by_name['service']._options = None
  _GETSERVICEDESIREDSTATEHISTORYREQ.fields_by_name['service']._serialized_options = b'\372B\004r\002\020\001'
  _GETDESIREDSTATEREQ.fields_by_name['desired_state_id']._options = None
  _GETDESIREDSTATEREQ.fields_by_name['desired_state_id']._serialized_options = b'\372B\004r\002\020\001'
  _GETDESIREDSTATEGRAPHREQ_QUERYBYSERVICE.fields_by_name['application']._options = None
  _GETDESIREDSTATEGRAPHREQ_QUERYBYSERVICE.fields_by_name['application']._serialized_options = b'\372B\004r\002\020\001'
  _GETDESIREDSTATEGRAPHREQ_QUERYBYSERVICE.fields_by_name['service']._options = None
  _GETDESIREDSTATEGRAPHREQ_QUERYBYSERVICE.fields_by_name['service']._serialized_options = b'\372B\004r\002\020\001'
  _GETDESIREDSTATEGRAPHREQ.fields_by_name['desired_state_id']._options = None
  _GETDESIREDSTATEGRAPHREQ.fields_by_name['desired_state_id']._serialized_options = b'\372B\004r\002\020\001'
  _GETSERVICELATESTDESIREDSTATEIDREQ.fields_by_name['application']._options = None
  _GETSERVICELATESTDESIREDSTATEIDREQ.fields_by_name['application']._serialized_options = b'\372B\004r\002\020\001'
  _GETSERVICELATESTDESIREDSTATEIDREQ.fields_by_name['service']._options = None
  _GETSERVICELATESTDESIREDSTATEIDREQ.fields_by_name['service']._serialized_options = b'\372B\004r\002\020\001'
  _GETSERVICEDESIREDSTATEIDHISTORYREQ.fields_by_name['application']._options = None
  _GETSERVICEDESIREDSTATEIDHISTORYREQ.fields_by_name['application']._serialized_options = b'\372B\004r\002\020\001'
  _GETSERVICEDESIREDSTATEIDHISTORYREQ.fields_by_name['service']._options = None
  _GETSERVICEDESIREDSTATEIDHISTORYREQ.fields_by_name['service']._serialized_options = b'\372B\004r\002\020\001'
  _SETMANUALAPPROVALREQ.fields_by_name['desired_state_id']._options = None
  _SETMANUALAPPROVALREQ.fields_by_name['desired_state_id']._serialized_options = b'\372B\004r\002\020\001'
  _SETMANUALAPPROVALREQ.fields_by_name['topic']._options = None
  _SETMANUALAPPROVALREQ.fields_by_name['topic']._serialized_options = b'\372B\004r\002\020\001'
  _PROMOTEDELIVERYREQ.fields_by_name['desired_state_id']._options = None
  _PROMOTEDELIVERYREQ.fields_by_name['desired_state_id']._serialized_options = b'\372B\004r\002\020\001'
  _PROMOTEDELIVERYREQ.fields_by_name['source']._options = None
  _PROMOTEDELIVERYREQ.fields_by_name['source']._serialized_options = b'\372B\004r\002\020\001'
  _BYPASSPROTECTIONREQ.fields_by_name['desired_state_id']._options = None
  _BYPASSPROTECTIONREQ.fields_by_name['desired_state_id']._serialized_options = b'\372B\004r\002\020\001'
  _BYPASSPROTECTIONREQ.fields_by_name['source']._options = None
  _BYPASSPROTECTIONREQ.fields_by_name['source']._serialized_options = b'\372B\004r\002\020\001'
  _LISTMAESTRORELEASESREQ.fields_by_name['entity_id']._options = None
  _LISTMAESTRORELEASESREQ.fields_by_name['entity_id']._serialized_options = b'\372B\005\212\001\002\020\001'
  _GETMAESTRORELEASEREQ.fields_by_name['release_id']._options = None
  _GETMAESTRORELEASEREQ.fields_by_name['release_id']._serialized_options = b'\372B\004r\002\020\001'
  _LISTCOMBINEDRELEASESREQ.fields_by_name['entity_id']._options = None
  _LISTCOMBINEDRELEASESREQ.fields_by_name['entity_id']._serialized_options = b'\372B\005\212\001\002\020\001'
  _LISTSERVICECOMBINEDRELEASESREQ.fields_by_name['application']._options = None
  _LISTSERVICECOMBINEDRELEASESREQ.fields_by_name['application']._serialized_options = b'\372B\004r\002\020\001'
  _LISTSERVICECOMBINEDRELEASESREQ.fields_by_name['service']._options = None
  _LISTSERVICECOMBINEDRELEASESREQ.fields_by_name['service']._serialized_options = b'\372B\004r\002\020\001'
  _GETLATESTCOMBINEDRELEASEDESIREDSTATEREQ.fields_by_name['entity_id']._options = None
  _GETLATESTCOMBINEDRELEASEDESIREDSTATEREQ.fields_by_name['entity_id']._serialized_options = b'\372B\005\212\001\002\020\001'
  _GETSERVICELATESTCOMBINEDRELEASEDESIREDSTATEREQ.fields_by_name['application']._options = None
  _GETSERVICELATESTCOMBINEDRELEASEDESIREDSTATEREQ.fields_by_name['application']._serialized_options = b'\372B\004r\002\020\001'
  _GETSERVICELATESTCOMBINEDRELEASEDESIREDSTATEREQ.fields_by_name['service']._options = None
  _GETSERVICELATESTCOMBINEDRELEASEDESIREDSTATEREQ.fields_by_name['service']._serialized_options = b'\372B\004r\002\020\001'
  _DESIREDSTATEMANAGER.methods_by_name['SetDesiredState']._options = None
  _DESIREDSTATEMANAGER.methods_by_name['SetDesiredState']._serialized_options = b'\202\323\344\223\002\027\"\022/v1/desired_states:\001*'
  _DESIREDSTATEMANAGER.methods_by_name['PreviewEntityGraph']._options = None
  _DESIREDSTATEMANAGER.methods_by_name['PreviewEntityGraph']._serialized_options = b'\202\323\344\223\002\037\"\032/v1/desired_states/preview:\001*'
  _DESIREDSTATEMANAGER.methods_by_name['GetServiceDesiredStateConvergenceSummary']._options = None
  _DESIREDSTATEMANAGER.methods_by_name['GetServiceDesiredStateConvergenceSummary']._serialized_options = b'\202\323\344\223\002L\022J/v1/applications/{application=*}/services/{service=*}/latest_desired_state'
  _DESIREDSTATEMANAGER.methods_by_name['GetServiceLatestDesiredStateId']._options = None
  _DESIREDSTATEMANAGER.methods_by_name['GetServiceLatestDesiredStateId']._serialized_options = b'\202\323\344\223\002O\022M/v1/applications/{application=*}/services/{service=*}/latest_desired_state_id'
  _DESIREDSTATEMANAGER.methods_by_name['GetServiceDesiredStateIdHistory']._options = None
  _DESIREDSTATEMANAGER.methods_by_name['GetServiceDesiredStateIdHistory']._serialized_options = b'\202\323\344\223\002P\022N/v1/applications/{application=*}/services/{service=*}/desired_state_id_history'
  _DESIREDSTATEMANAGER.methods_by_name['GetServiceLastConvergedStates']._options = None
  _DESIREDSTATEMANAGER.methods_by_name['GetServiceLastConvergedStates']._serialized_options = b'\202\323\344\223\002F\022D/v1/applications/{application=*}/services/{service=*}/last_converged'
  _DESIREDSTATEMANAGER.methods_by_name['GetServiceDesiredStateHistory']._options = None
  _DESIREDSTATEMANAGER.methods_by_name['GetServiceDesiredStateHistory']._serialized_options = b'\202\323\344\223\002F\022D/v1/applications/{application=*}/services/{service=*}/desired_states'
  _DESIREDSTATEMANAGER.methods_by_name['GetDesiredState']._options = None
  _DESIREDSTATEMANAGER.methods_by_name['GetDesiredState']._serialized_options = b'\202\323\344\223\002)\022\'/v1/desired_states/{desired_state_id=*}'
  _DESIREDSTATEMANAGER.methods_by_name['GetDesiredStateGraph']._options = None
  _DESIREDSTATEMANAGER.methods_by_name['GetDesiredStateGraph']._serialized_options = b'\202\323\344\223\002\035\"\030/v1/desired_states/graph:\001*'
  _DESIREDSTATEMANAGER.methods_by_name['GetDesiredStateConvergenceSummary']._options = None
  _DESIREDSTATEMANAGER.methods_by_name['GetDesiredStateConvergenceSummary']._serialized_options = b'\202\323\344\223\0021\022//v1/desired_states/{desired_state_id=*}/summary'
  _DESIREDSTATEMANAGER.methods_by_name['ValidateDesiredState']._options = None
  _DESIREDSTATEMANAGER.methods_by_name['ValidateDesiredState']._serialized_options = b'\202\323\344\223\002 \"\033/v1/desired_states/validate:\001*'
  _DESIREDSTATEMANAGER.methods_by_name['SetManualApproval']._options = None
  _DESIREDSTATEMANAGER.methods_by_name['SetManualApproval']._serialized_options = b'\202\323\344\223\0020\"+/v1/desired_states/approve_manual_condition:\001*'
  _DESIREDSTATEMANAGER.methods_by_name['PromoteDelivery']._options = None
  _DESIREDSTATEMANAGER.methods_by_name['PromoteDelivery']._serialized_options = b'\202\323\344\223\002(\"#/v1/desired_states/promote_delivery:\001*'
  _DESIREDSTATEMANAGER.methods_by_name['BypassProtection']._options = None
  _DESIREDSTATEMANAGER.methods_by_name['BypassProtection']._serialized_options = b'\202\323\344\223\002)\"$/v1/desired_states/bypass_protection:\001*'
  _DESIREDSTATEMANAGER.methods_by_name['ListMaestroReleases']._options = None
  _DESIREDSTATEMANAGER.methods_by_name['ListMaestroReleases']._serialized_options = b'\202\323\344\223\002%\022#/v1/desired_states/maestro_releases'
  _DESIREDSTATEMANAGER.methods_by_name['GetMaestroRelease']._options = None
  _DESIREDSTATEMANAGER.methods_by_name['GetMaestroRelease']._serialized_options = b'\202\323\344\223\0024\0222/v1/desired_states/maestro_releases/{release_id=*}'
  _DESIREDSTATEMANAGER.methods_by_name['ListCombinedReleases']._options = None
  _DESIREDSTATEMANAGER.methods_by_name['ListCombinedReleases']._serialized_options = b'\202\323\344\223\002&\022$/v1/desired_states/combined_releases'
  _DESIREDSTATEMANAGER.methods_by_name['ListServiceCombinedReleases']._options = None
  _DESIREDSTATEMANAGER.methods_by_name['ListServiceCombinedReleases']._serialized_options = b'\202\323\344\223\002I\022G/v1/applications/{application=*}/services/{service=*}/combined_releases'
  _DESIREDSTATEMANAGER.methods_by_name['GetLatestCombinedReleaseDesiredState']._options = None
  _DESIREDSTATEMANAGER.methods_by_name['GetLatestCombinedReleaseDesiredState']._serialized_options = b'\202\323\344\223\002;\0229/v1/desired_states/combined_releases/latest_desired_state'
  _DESIREDSTATEMANAGER.methods_by_name['GetServiceLatestCombinedReleaseDesiredState']._options = None
  _DESIREDSTATEMANAGER.methods_by_name['GetServiceLatestCombinedReleaseDesiredState']._serialized_options = b'\202\323\344\223\002^\022\\/v1/applications/{application=*}/services/{service=*}/combined_releases/latest_desired_state'
  _DESIREDSTATEMANAGER.methods_by_name['GetDebugState']._options = None
  _DESIREDSTATEMANAGER.methods_by_name['GetDebugState']._serialized_options = b'\202\323\344\223\002/\022-/v1/desired_states/{desired_state_id=*}/debug'
  _globals['_SETDESIREDSTATEREQ']._serialized_start=454
  _globals['_SETDESIREDSTATEREQ']._serialized_end=828
  _globals['_VALIDATEDESIREDSTATEREQ']._serialized_start=831
  _globals['_VALIDATEDESIREDSTATEREQ']._serialized_end=1139
  _globals['_SETDESIREDSTATERESP']._serialized_start=1141
  _globals['_SETDESIREDSTATERESP']._serialized_end=1224
  _globals['_PREVIEWENTITYGRAPHRESP']._serialized_start=1226
  _globals['_PREVIEWENTITYGRAPHRESP']._serialized_end=1341
  _globals['_GETSERVICEDESIREDSTATECONVERGENCESUMMARYREQ']._serialized_start=1344
  _globals['_GETSERVICEDESIREDSTATECONVERGENCESUMMARYREQ']._serialized_end=1480
  _globals['_STATUSEXPLANATIONS']._serialized_start=1482
  _globals['_STATUSEXPLANATIONS']._serialized_end=1580
  _globals['_DEBUGLOGS']._serialized_start=1582
  _globals['_DEBUGLOGS']._serialized_end=1653
  _globals['_PENDINGSETDESIREDSTATE']._serialized_start=1656
  _globals['_PENDINGSETDESIREDSTATE']._serialized_end=1883
  _globals['_DESIREDSTATESUMMARY']._serialized_start=1886
  _globals['_DESIREDSTATESUMMARY']._serialized_end=4248
  _globals['_DESIREDSTATESUMMARY_STATUSESENTRY']._serialized_start=3491
  _globals['_DESIREDSTATESUMMARY_STATUSESENTRY']._serialized_end=3576
  _globals['_DESIREDSTATESUMMARY_PRECONDITIONSTATUSESENTRY']._serialized_start=3578
  _globals['_DESIREDSTATESUMMARY_PRECONDITIONSTATUSESENTRY']._serialized_end=3683
  _globals['_DESIREDSTATESUMMARY_STATUSEXPLANATIONSENTRY']._serialized_start=3685
  _globals['_DESIREDSTATESUMMARY_STATUSEXPLANATIONSENTRY']._serialized_end=3786
  _globals['_DESIREDSTATESUMMARY_DEBUGLOGSENTRY']._serialized_start=3788
  _globals['_DESIREDSTATESUMMARY_DEBUGLOGSENTRY']._serialized_end=3871
  _globals['_DESIREDSTATESUMMARY_ACTIONEXPLANATIONSENTRY']._serialized_start=3873
  _globals['_DESIREDSTATESUMMARY_ACTIONEXPLANATIONSENTRY']._serialized_end=3979
  _globals['_DESIREDSTATESUMMARY_LASTUPDATETIMESTAMPSENTRY']._serialized_start=3981
  _globals['_DESIREDSTATESUMMARY_LASTUPDATETIMESTAMPSENTRY']._serialized_end=4068
  _globals['_DESIREDSTATESUMMARY_LASTFETCHEDTIMESTAMPSENTRY']._serialized_start=4070
  _globals['_DESIREDSTATESUMMARY_LASTFETCHEDTIMESTAMPSENTRY']._serialized_end=4158
  _globals['_DESIREDSTATESUMMARY_LASTAPPLIEDTIMESTAMPSENTRY']._serialized_start=4160
  _globals['_DESIREDSTATESUMMARY_LASTAPPLIEDTIMESTAMPSENTRY']._serialized_end=4248
  _globals['_GETDESIREDSTATECONVERGENCEREQ']._serialized_start=4250
  _globals['_GETDESIREDSTATECONVERGENCEREQ']._serialized_end=4351
  _globals['_GETDESIREDSTATECONVERGENCESUMMARYRESP']._serialized_start=4353
  _globals['_GETDESIREDSTATECONVERGENCESUMMARYRESP']._serialized_end=4454
  _globals['_GETSERVICEDESIREDSTATECONVERGENCESUMMARYRESP']._serialized_start=4456
  _globals['_GETSERVICEDESIREDSTATECONVERGENCESUMMARYRESP']._serialized_end=4564
  _globals['_GETSERVICELASTCONVERGEDSTATEREQ']._serialized_start=4566
  _globals['_GETSERVICELASTCONVERGEDSTATEREQ']._serialized_end=4655
  _globals['_GETSERVICELASTCONVERGEDSTATERESP']._serialized_start=4657
  _globals['_GETSERVICELASTCONVERGEDSTATERESP']._serialized_end=4776
  _globals['_GETSERVICEDESIREDSTATEHISTORYREQ']._serialized_start=4779
  _globals['_GETSERVICEDESIREDSTATEHISTORYREQ']._serialized_end=4943
  _globals['_GETSERVICEDESIREDSTATEHISTORYRESP']._serialized_start=4946
  _globals['_GETSERVICEDESIREDSTATEHISTORYRESP']._serialized_end=5075
  _globals['_GETDESIREDSTATEREQ']._serialized_start=5077
  _globals['_GETDESIREDSTATEREQ']._serialized_end=5132
  _globals['_GETDESIREDSTATERESP']._serialized_start=5135
  _globals['_GETDESIREDSTATERESP']._serialized_end=5533
  _globals['_GETDESIREDSTATEGRAPHREQ']._serialized_start=5536
  _globals['_GETDESIREDSTATEGRAPHREQ']._serialized_end=6197
  _globals['_GETDESIREDSTATEGRAPHREQ_QUERYBYSERVICE']._serialized_start=6010
  _globals['_GETDESIREDSTATEGRAPHREQ_QUERYBYSERVICE']._serialized_end=6082
  _globals['_GETDESIREDSTATEGRAPHREQ_DEPTHOVERRIDEBYSTATUS']._serialized_start=6084
  _globals['_GETDESIREDSTATEGRAPHREQ_DEPTHOVERRIDEBYSTATUS']._serialized_end=6176
  _globals['_DESIREDSTATETIMESTAMPS']._serialized_start=6200
  _globals['_DESIREDSTATETIMESTAMPS']._serialized_end=6395
  _globals['_GETDESIREDSTATEGRAPHRESP']._serialized_start=6398
  _globals['_GETDESIREDSTATEGRAPHRESP']._serialized_end=6640
  _globals['_GETSERVICELATESTDESIREDSTATEIDREQ']._serialized_start=6642
  _globals['_GETSERVICELATESTDESIREDSTATEIDREQ']._serialized_end=6733
  _globals['_GETSERVICELATESTDESIREDSTATEIDRESP']._serialized_start=6736
  _globals['_GETSERVICELATESTDESIREDSTATEIDRESP']._serialized_end=6881
  _globals['_GETSERVICEDESIREDSTATEIDHISTORYREQ']._serialized_start=6884
  _globals['_GETSERVICEDESIREDSTATEIDHISTORYREQ']._serialized_end=7015
  _globals['_GETSERVICEDESIREDSTATEIDHISTORYRESP']._serialized_start=7017
  _globals['_GETSERVICEDESIREDSTATEIDHISTORYRESP']._serialized_end=7106
  _globals['_VALIDATEDESIREDSTATERESP']._serialized_start=7109
  _globals['_VALIDATEDESIREDSTATERESP']._serialized_end=7264
  _globals['_SETMANUALAPPROVALREQ']._serialized_start=7266
  _globals['_SETMANUALAPPROVALREQ']._serialized_end=7390
  _globals['_SETMANUALAPPROVALRESP']._serialized_start=7392
  _globals['_SETMANUALAPPROVALRESP']._serialized_end=7415
  _globals['_PROMOTEDELIVERYREQ']._serialized_start=7417
  _globals['_PROMOTEDELIVERYREQ']._serialized_end=7542
  _globals['_PROMOTEDELIVERYRESP']._serialized_start=7544
  _globals['_PROMOTEDELIVERYRESP']._serialized_end=7565
  _globals['_BYPASSPROTECTIONREQ']._serialized_start=7567
  _globals['_BYPASSPROTECTIONREQ']._serialized_end=7648
  _globals['_BYPASSPROTECTIONRESP']._serialized_start=7650
  _globals['_BYPASSPROTECTIONRESP']._serialized_end=7672
  _globals['_LISTMAESTRORELEASESREQ']._serialized_start=7675
  _globals['_LISTMAESTRORELEASESREQ']._serialized_end=7858
  _globals['_LISTMAESTRORELEASESRESP']._serialized_start=7860
  _globals['_LISTMAESTRORELEASESRESP']._serialized_end=7984
  _globals['_GETMAESTRORELEASEREQ']._serialized_start=7986
  _globals['_GETMAESTRORELEASEREQ']._serialized_end=8037
  _globals['_GETMAESTRORELEASERESP']._serialized_start=8039
  _globals['_GETMAESTRORELEASERESP']._serialized_end=8135
  _globals['_LISTCOMBINEDRELEASESREQ']._serialized_start=8138
  _globals['_LISTCOMBINEDRELEASESREQ']._serialized_end=8293
  _globals['_LISTSERVICECOMBINEDRELEASESREQ']._serialized_start=8296
  _globals['_LISTSERVICECOMBINEDRELEASESREQ']._serialized_end=8443
  _globals['_LISTCOMBINEDRELEASESRESP']._serialized_start=8446
  _globals['_LISTCOMBINEDRELEASESRESP']._serialized_end=8708
  _globals['_LISTCOMBINEDRELEASESRESP_RELEASE']._serialized_start=8576
  _globals['_LISTCOMBINEDRELEASESRESP_RELEASE']._serialized_end=8708
  _globals['_GETLATESTCOMBINEDRELEASEDESIREDSTATEREQ']._serialized_start=8710
  _globals['_GETLATESTCOMBINEDRELEASEDESIREDSTATEREQ']._serialized_end=8822
  _globals['_GETSERVICELATESTCOMBINEDRELEASEDESIREDSTATEREQ']._serialized_start=8824
  _globals['_GETSERVICELATESTCOMBINEDRELEASEDESIREDSTATEREQ']._serialized_end=8928
  _globals['_GETLATESTCOMBINEDRELEASEDESIREDSTATERESP']._serialized_start=8931
  _globals['_GETLATESTCOMBINEDRELEASEDESIREDSTATERESP']._serialized_end=9356
  _globals['_DESIREDSTATEMANAGER']._serialized_start=9359
  _globals['_DESIREDSTATEMANAGER']._serialized_end=13484
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/organization/user_metadata.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from prodvana.proto.prodvana.common_config import links_pb2 as prodvana_dot_common__config_dot_links__pb2
from prodvana.proto.validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)prodvana/organization/user_metadata.proto\x12\x15prodvana.organization\x1a\"prodvana/common_config/links.proto\x1a\x17validate/validate.proto\"\xe2\x01\n\x18OrganizationUserMetadata\x12\x46\n\x11\x61pplication_links\x18\x01 \x03(\x0b\x32\x1c.prodvana.common_config.LinkB\r\xfa\x42\n\x92\x01\x07\"\x05\x8a\x01\x02\x10\x01\x12\x42\n\rservice_links\x18\x02 \x03(\x0b\x32\x1c.prodvana.common_config.LinkB\r\xfa\x42\n\x92\x01\x07\"\x05\x8a\x01\x02\x10\x01\x12:\n\x05links\x18\x03 \x03(\x0b\x32\x1c.prodvana.common_config.LinkB\r\xfa\x42\n\x92\x01\x07\"\x05\x8a\x01\x02\x10\x01\x42QZOgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/organizationb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'prodvana.organization.user_metadata_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZOgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/organization'
  _ORGANIZATIONUSERMETADATA.fields_by_name['application_links']._options = None
  _ORGANIZATIONUSERMETADATA.fields_by_name['application_links']._serialized_options = b'\372B\n\222\001\007\"\005\212\001\002\020\001'
  _ORGANIZATIONUSERMETADATA.fields_by_name['service_links']._options = None
  _ORGANIZATIONUSERMETADATA.fields_by_name['service_links']._serialized_options = b'\372B\n\222\001\007\"\005\212\001\002\020\001'
  _ORGANIZATIONUSERMETADATA.fields_by_name['links']._options = None
  _ORGANIZATIONUSERMETADATA.fields_by_name['links']._serialized_options = b'\372B\n\222\001\007\"\005\212\001\002\020\001'
  _globals['_ORGANIZATIONUSERMETADATA']._serialized_start=130
  _globals['_ORGANIZATIONUSERMETADATA']._serialized_end=356
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from prodvana.proto.prodvana.settings.organization import users_pb2 as prodvana_dot_settings_dot_organization_dot_users__pb2


class UsersSettingsManagerStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetUser = channel.unary_unary(
                '/prodvana.settings.organization.UsersSettingsManager/GetUser',
                request_serializer=prodvana_dot_settings_dot_organization_dot_users__pb2.GetUserReq.SerializeToString,
                response_deserializer=prodvana_dot_settings_dot_organization_dot_users__pb2.GetUserResp.FromString,
                )
        self.ListUsers = channel.unary_unary(
                '/prodvana.settings.organization.UsersSettingsManager/ListUsers',
                request_serializer=prodvana_dot_settings_dot_organization_dot_users__pb2.ListUsersReq.SerializeToString,
                response_deserializer=prodvana_dot_settings_dot_organization_dot_users__pb2.ListUsersResp.FromString,
                )
        self.ListRoles = channel.unary_unary(
                '/prodvana.settings.organization.UsersSettingsManager/ListRoles',
                request_serializer=prodvana_dot_settings_dot_organization_dot_users__pb2.ListRolesReq.SerializeToString,
                response_deserializer=prodvana_dot_settings_dot_organization_dot_users__pb2.ListRolesResp.FromString,
                )
        self.SetRoles = channel.unary_unary(
                '/prodvana.settings.organization.UsersSettingsManager/SetRoles',
                request_serializer=prodvana_dot_settings_dot_organization_dot_users__pb2.SetRolesReq.SerializeToString,
                response_deserializer=prodvana_dot_settings_dot_organization_dot_users__pb2.SetRolesResp.FromString,
                )
        self.InviteUsers = channel.unary_unary(
                '/prodvana.settings.organization.UsersSettingsManager/InviteUsers',
                request_serializer=prodvana_dot_settings_dot_organization_dot_users__pb2.InviteUsersReq.SerializeToString,
                response_deserializer=prodvana_dot_settings_dot_organization_dot_users__pb2.InviteUsersResp.FromString,
                )
        self.OrganizationSupportsInvites = channel.unary_unary(
                '/prodvana.settings.organization.UsersSettingsManager/OrganizationSupportsInvites',
                request_serializer=prodvana_dot_settings_dot_organization_dot_users__pb2.OrganizationSupportsInvitesReq.SerializeToString,
                response_deserializer=prodvana_dot_settings_dot_organization_dot_users__pb2.OrganizationSupportsInvitesResp.FromString,
                )
        self.RemoveUser = channel.unary_unary(
                '/prodvana.settings.organization.UsersSettingsManager/RemoveUser',
                request_serializer=prodvana_dot_settings_dot_organization_dot_users__pb2.RemoveUserReq.SerializeToString,
                response_deserializer=prodvana_dot_settings_dot_organization_dot_users__pb2.RemoveUserResp.FromString,
                )


class UsersSettingsManagerServicer(object):
    """Missing associated documentation comment in .proto file."""

    def GetUser(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListUsers(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListRoles(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetRoles(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def InviteUsers(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def OrganizationSupportsInvites(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RemoveUser(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_UsersSettingsManagerServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetUser': grpc.unary_unary_rpc_method_handler(
                    servicer.GetUser,
                    request_deserializer=prodvana_dot_settings_dot_organization_dot_users__pb2.GetUserReq.FromString,
                    response_serializer=prodvana_dot_settings_dot_organization_dot_users__pb2.GetUserResp.SerializeToString,
            ),
            'ListUsers': grpc.unary_unary_rpc_method_handler(
                    servicer.ListUsers,
                    request_deserializer=prodvana_dot_settings_dot_organization_dot_users__pb2.ListUsersReq.FromString,
                    response_serializer=prodvana_dot_settings_dot_organization_dot_users__pb2.ListUsersResp.SerializeToString,
            ),
            'ListRoles': grpc.unary_unary_rpc_method_handler(
                    servicer.ListRoles,
                    request_deserializer=prodvana_dot_settings_dot_organization_dot_users__pb2.ListRolesReq.FromString,
                    response_serializer=prodvana_dot_settings_dot_organization_dot_users__pb2.ListRolesResp.SerializeToString,
            ),
            'SetRoles': grpc.unary_unary_rpc_method_handler(
                    servicer.SetRoles,
                    request_deserializer=prodvana_dot_settings_dot_organization_dot_users__pb2.SetRolesReq.FromString,
                    response_serializer=prodvana_dot_settings_dot_organization_dot_users__pb2.SetRolesResp.SerializeToString,
            ),
            'InviteUsers': grpc.unary_unary_rpc_method_handler(
                    servicer.InviteUsers,
                    request_deserializer=prodvana_dot_settings_dot_organization_dot_users__pb2.InviteUsersReq.FromString,
                    response_serializer=prodvana_dot_settings_dot_organization_dot_users__pb2.InviteUsersResp.SerializeToString,
            ),
            'OrganizationSupportsInvites': grpc.unary_unary_rpc_method_handler(
                    servicer.OrganizationSupportsInvites,
                    request_deserializer=prodvana_dot_settings_dot_organization_dot_users__pb2.OrganizationSupportsInvitesReq.FromString,
                    response_serializer=prodvana_dot_settings_dot_organization_dot_users__pb2.OrganizationSupportsInvitesResp.SerializeToString,
            ),
            'RemoveUser': grpc.unary_unary_rpc_method_handler(
                    servicer.RemoveUser,
                    request_deserializer=prodvana_dot_settings_dot_organization_dot_users__pb2.RemoveUserReq.FromString,
                    response_serializer=prodvana_dot_settings_dot_organization_dot_users__pb2.RemoveUserResp.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'prodvana.settings.organization.UsersSettingsManager', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class UsersSettingsManager(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def GetUser(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.settings.organization.UsersSettingsManager/GetUser',
            prodvana_dot_settings_dot_organization_dot_users__pb2.GetUserReq.SerializeToString,
            prodvana_dot_settings_dot_organization_dot_users__pb2.GetUserResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListUsers(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.settings.organization.UsersSettingsManager/ListUsers',
            prodvana_dot_settings_dot_organization_dot_users__pb2.ListUsersReq.SerializeToString,
            prodvana_dot_settings_dot_organization_dot_users__pb2.ListUsersResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListRoles(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.settings.organization.UsersSettingsManager/ListRoles',
            prodvana_dot_settings_dot_organization_dot_users__pb2.ListRolesReq.SerializeToString,
            prodvana_dot_settings_dot_organization_dot_users__pb2.ListRolesResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetRoles(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.settings.organization.UsersSettingsManager/SetRoles',
            prodvana_dot_settings_dot_organization_dot_users__pb2.SetRolesReq.SerializeToString,
            prodvana_dot_settings_dot_organization_dot_users__pb2.SetRolesResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def InviteUsers(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.settings.organization.UsersSettingsManager/InviteUsers',
            prodvana_dot_settings_dot_organization_dot_users__pb2.InviteUsersReq.SerializeToString,
            prodvana_dot_settings_dot_organization_dot_users__pb2.InviteUsersResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def OrganizationSupportsInvites(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.settings.organization.UsersSettingsManager/OrganizationSupportsInvites',
            prodvana_dot_settings_dot_organization_dot_users__pb2.OrganizationSupportsInvitesReq.SerializeToString,
            prodvana_dot_settings_dot_organization_dot_users__pb2.OrganizationSupportsInvitesResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RemoveUser(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.settings.organization.UsersSettingsManager/RemoveUser',
            prodvana_dot_settings_dot_organization_dot_users__pb2.RemoveUserReq.SerializeToString,
            prodvana_dot_settings_dot_organization_dot_users__pb2.RemoveUserResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/desired_state/model/entity.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from prodvana.proto.prodvana.common_config import task_pb2 as prodvana_dot_common__config_dot_task__pb2
from prodvana.proto.prodvana.desired_state.model import desired_state_pb2 as prodvana_dot_desired__state_dot_model_dot_desired__state__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)prodvana/desired_state/model/entity.proto\x12\x1cprodvana.desired_state.model\x1a!prodvana/common_config/task.proto\x1a\x30prodvana/desired_state/model/desired_state.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\x93\t\n\rNotifications\x12U\n\x10program_failures\x18\x01 \x01(\x0b\x32;.prodvana.desired_state.model.Notifications.ProgramFailures\x12T\n\x10runtime_failures\x18\x02 \x03(\x0b\x32:.prodvana.desired_state.model.Notifications.RuntimeFailure\x12Y\n\x12protection_failure\x18\x03 \x03(\x0b\x32=.prodvana.desired_state.model.Notifications.ProtectionFailure\x12n\n\x1d\x63onvergence_extension_failure\x18\x04 \x03(\x0b\x32G.prodvana.desired_state.model.Notifications.ConvergenceExtensionFailure\x12[\n\x13\x64\x65layed_convergence\x18\x05 \x01(\x0b\x32>.prodvana.desired_state.model.Notifications.DelayedConvergence\x12\x61\n!concurrency_limit_exceeded_errors\x18\x06 \x03(\x0b\x32\x36.prodvana.desired_state.model.ConcurrencyLimitExceeded\x1a\x61\n\x0fProgramFailures\x12\x15\n\rfailure_count\x18\x01 \x01(\x05\x12\x37\n\x13most_recent_failure\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x1a\x9b\x02\n\x0eRuntimeFailure\x12\\\n\x0c\x66\x61ilure_type\x18\x01 \x01(\x0e\x32\x46.prodvana.desired_state.model.Notifications.RuntimeFailure.FailureType\x12\x0f\n\x07message\x18\x02 \x01(\t\"\x99\x01\n\x0b\x46\x61ilureType\x12\x0b\n\x07UNKNOWN\x10\x00\x12 \n\x1c\x45XTENSION_FETCH_INVOKE_ERROR\x10\x01\x12 \n\x1c\x45XTENSION_FETCH_RESULT_ERROR\x10\x02\x12\x17\n\x13RUNTIME_APPLY_ERROR\x10\x03\x12 \n\x1c\x45XTENSION_APPLY_INVOKE_ERROR\x10\x04\x1aT\n\x11ProtectionFailure\x12?\n\rprotection_id\x18\x01 \x01(\x0b\x32(.prodvana.desired_state.model.Identifier\x1a]\n\x1b\x43onvergenceExtensionFailure\x12>\n\x0c\x65xtension_id\x18\x01 \x01(\x0b\x32(.prodvana.desired_state.model.Identifier\x1a\x14\n\x12\x44\x65layedConvergence\"\x80\x0b\n\x06\x45ntity\x12\x34\n\x02id\x18\x01 \x01(\x0b\x32(.prodvana.desired_state.model.Identifier\x12\x18\n\x10\x64\x65sired_state_id\x18\x02 \x01(\t\x12\x1d\n\x15root_desired_state_id\x18\x03 \x01(\t\x12>\n\x0b\x61nnotations\x18\x04 \x01(\x0b\x32).prodvana.desired_state.model.Annotations\x12\x34\n\x06status\x18\x05 \x01(\x0e\x32$.prodvana.desired_state.model.Status\x12\x41\n\rsimple_status\x18\x11 \x01(\x0e\x32*.prodvana.desired_state.model.SimpleStatus\x12;\n\x0estarting_state\x18\x06 \x01(\x0b\x32#.prodvana.desired_state.model.State\x12<\n\x0flast_seen_state\x18\x07 \x01(\x0b\x32#.prodvana.desired_state.model.State\x12:\n\rdesired_state\x18\x08 \x01(\x0b\x32#.prodvana.desired_state.model.State\x12\x39\n\x0ctarget_state\x18\x13 \x01(\x0b\x32#.prodvana.desired_state.model.State\x12K\n\x15precondition_statuses\x18\t \x03(\x0b\x32,.prodvana.desired_state.model.ConditionState\x12L\n\x13status_explanations\x18\n \x03(\x0b\x32/.prodvana.desired_state.model.StatusExplanation\x12\x34\n\x04logs\x18\x0b \x03(\x0b\x32&.prodvana.desired_state.model.DebugLog\x12K\n\x12\x61\x63tion_explanation\x18\x0c \x01(\x0b\x32/.prodvana.desired_state.model.ActionExplanation\x12\x39\n\x15last_update_timestamp\x18\r \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12:\n\x16last_fetched_timestamp\x18\x0e \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12:\n\x16last_applied_timestamp\x18\x0f \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12>\n\x0c\x64\x65pendencies\x18\x10 \x03(\x0b\x32(.prodvana.desired_state.model.Identifier\x12\x45\n\x13\x64irect_dependencies\x18\x17 \x03(\x0b\x32(.prodvana.desired_state.model.Identifier\x12\x38\n\tlifecycle\x18\x12 \x01(\x0e\x32%.prodvana.common_config.TaskLifecycle\x12G\n\x10missing_approval\x18\x14 \x01(\x0b\x32-.prodvana.desired_state.model.MissingApproval\x12=\n\x0b\x61pply_error\x18\x15 \x01(\x0b\x32(.prodvana.desired_state.model.ApplyError\x12\x42\n\rnotifications\x18\x16 \x01(\x0b\x32+.prodvana.desired_state.model.Notifications\"}\n\x0b\x45ntityGraph\x12\x36\n\x04root\x18\x01 \x01(\x0b\x32(.prodvana.desired_state.model.Identifier\x12\x36\n\x08\x65ntities\x18\x02 \x03(\x0b\x32$.prodvana.desired_state.model.EntityBXZVgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/desired_state/modelb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'prodvana.desired_state.model.entity_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZVgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/desired_state/model'
  _globals['_NOTIFICATIONS']._serialized_start=194
  _globals['_NOTIFICATIONS']._serialized_end=1365
  _globals['_NOTIFICATIONS_PROGRAMFAILURES']._serialized_start=779
  _globals['_NOTIFICATIONS_PROGRAMFAILURES']._serialized_end=876
  _globals['_NOTIFICATIONS_RUNTIMEFAILURE']._serialized_start=879
  _globals['_NOTIFICATIONS_RUNTIMEFAILURE']._serialized_end=1162
  _globals['_NOTIFICATIONS_RUNTIMEFAILURE_FAILURETYPE']._serialized_start=1009
  _globals['_NOTIFICATIONS_RUNTIMEFAILURE_FAILURETYPE']._serialized_end=1162
  _globals['_NOTIFICATIONS_PROTECTIONFAILURE']._serialized_start=1164
  _globals['_NOTIFICATIONS_PROTECTIONFAILURE']._serialized_end=1248
  _globals['_NOTIFICATIONS_CONVERGENCEEXTENSIONFAILURE']._serialized_start=1250
  _globals['_NOTIFICATIONS_CONVERGENCEEXTENSIONFAILURE']._serialized_end=1343
  _globals['_NOTIFICATIONS_DELAYEDCONVERGENCE']._serialized_start=1345
  _globals['_NOTIFICATIONS_DELAYEDCONVERGENCE']._serialized_end=1365
  _globals['_ENTITY']._serialized_start=1368
  _globals['_ENTITY']._serialized_end=2776
  _globals['_ENTITYGRAPH']._serialized_start=2778
  _globals['_ENTITYGRAPH']._serialized_end=2903
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/config_file/config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from prodvana.proto.prodvana.application import application_config_pb2 as prodvana_dot_application_dot_application__config__pb2
from prodvana.proto.prodvana.application import user_metadata_pb2 as prodvana_dot_application_dot_user__metadata__pb2
from prodvana.proto.prodvana.environment import clusters_pb2 as prodvana_dot_environment_dot_clusters__pb2
from prodvana.proto.prodvana.delivery_extension import config_pb2 as prodvana_dot_delivery__extension_dot_config__pb2
from prodvana.proto.prodvana.protection import protection_config_pb2 as prodvana_dot_protection_dot_protection__config__pb2
from prodvana.proto.prodvana.release_channel import release_channel_config_pb2 as prodvana_dot_release__channel_dot_release__channel__config__pb2
from prodvana.proto.prodvana.service import service_config_pb2 as prodvana_dot_service_dot_service__config__pb2
from prodvana.proto.prodvana.service import user_metadata_pb2 as prodvana_dot_service_dot_user__metadata__pb2
from prodvana.proto.validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!prodvana/config_file/config.proto\x12\x14prodvana.config_file\x1a-prodvana/application/application_config.proto\x1a(prodvana/application/user_metadata.proto\x1a#prodvana/environment/clusters.proto\x1a(prodvana/delivery_extension/config.proto\x1a+prodvana/protection/protection_config.proto\x1a\x35prodvana/release_channel/release_channel_config.proto\x1a%prodvana/service/service_config.proto\x1a$prodvana/service/user_metadata.proto\x1a\x17validate/validate.proto\"\xd1\x04\n\x0eProdvanaConfig\x12>\n\x0b\x61pplication\x18\x01 \x01(\x0b\x32\'.prodvana.application.ApplicationConfigH\x00\x12\x32\n\x07service\x18\x02 \x01(\x0b\x32\x1f.prodvana.service.ServiceConfigH\x00\x12;\n\nprotection\x18\x03 \x01(\x0b\x32%.prodvana.protection.ProtectionConfigH\x00\x12\x36\n\x07runtime\x18\x04 \x01(\x0b\x32#.prodvana.environment.ClusterConfigH\x00\x12R\n\x12\x64\x65livery_extension\x18\x07 \x01(\x0b\x32\x34.prodvana.delivery_extension.DeliveryExtensionConfigH\x00\x12I\n\x0frelease_channel\x18\x08 \x01(\x0b\x32..prodvana.release_channel.ReleaseChannelConfigH\x00\x12M\n\x14\x61pplication_metadata\x18\x05 \x01(\x0b\x32-.prodvana.application.ApplicationUserMetadataH\x01\x12\x41\n\x10service_metadata\x18\x06 \x01(\x0b\x32%.prodvana.service.ServiceUserMetadataH\x01\x42\x13\n\x0c\x63onfig_oneof\x12\x03\xf8\x42\x01\x42\x10\n\x0emetadata_oneofBPZNgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/config_fileb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'prodvana.config_file.config_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZNgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/config_file'
  _PRODVANACONFIG.oneofs_by_name['config_oneof']._options = None
  _PRODVANACONFIG.oneofs_by_name['config_oneof']._serialized_options = b'\370B\001'
  _globals['_PRODVANACONFIG']._serialized_start=430
  _globals['_PRODVANACONFIG']._serialized_end=1023
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/config_writeback/writeback.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)prodvana/config_writeback/writeback.proto\x12\x19prodvana.config_writeback\"A\n\x13\x43onfigWritebackPath\x12\x14\n\x0c\x64isplay_name\x18\x01 \x01(\t\x12\x14\n\x0c\x64isplay_path\x18\x02 \x01(\tBUZSgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/config_writebackb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'prodvana.config_writeback.writeback_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZSgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/config_writeback'
  _globals['_CONFIGWRITEBACKPATH']._serialized_start=72
  _globals['_CONFIGWRITEBACKPATH']._serialized_end=137
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import grpc
import prodvana.proto.prodvana.desired_state.debug.debug_pb2
import prodvana.proto.prodvana.desired_state.manager_pb2

class DesiredStateManagerStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    SetDesiredState: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.desired_state.manager_pb2.SetDesiredStateReq,
        prodvana.proto.prodvana.desired_state.manager_pb2.SetDesiredStateResp,
    ]
    PreviewEntityGraph: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.desired_state.manager_pb2.SetDesiredStateReq,
        prodvana.proto.prodvana.desired_state.manager_pb2.PreviewEntityGraphResp,
    ]
    """validate a SetDesiredState call and return a preview entity graph
    TODO(naphat) delete ValidateDesiredState and replace with this
    """
    GetServiceDesiredStateConvergenceSummary: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.desired_state.manager_pb2.GetServiceDesiredStateConvergenceSummaryReq,
        prodvana.proto.prodvana.desired_state.manager_pb2.GetServiceDesiredStateConvergenceSummaryResp,
    ]
    GetServiceLatestDesiredStateId: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.desired_state.manager_pb2.GetServiceLatestDesiredStateIdReq,
        prodvana.proto.prodvana.desired_state.manager_pb2.GetServiceLatestDesiredStateIdResp,
    ]
    GetServiceDesiredStateIdHistory: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.desired_state.manager_pb2.GetServiceDesiredStateIdHistoryReq,
        prodvana.proto.prodvana.desired_state.manager_pb2.GetServiceDesiredStateIdHistoryResp,
    ]
    GetServiceLastConvergedStates: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.desired_state.manager_pb2.GetServiceLastConvergedStateReq,
        prodvana.proto.prodvana.desired_state.manager_pb2.GetServiceLastConvergedStateResp,
    ]
    GetServiceDesiredStateHistory: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.desired_state.manager_pb2.GetServiceDesiredStateHistoryReq,
        prodvana.proto.prodvana.desired_state.manager_pb2.GetServiceDesiredStateHistoryResp,
    ]
    GetDesiredState: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.desired_state.manager_pb2.GetDesiredStateReq,
        prodvana.proto.prodvana.desired_state.manager_pb2.GetDesiredStateResp,
    ]
    GetDesiredStateGraph: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.desired_state.manager_pb2.GetDesiredStateGraphReq,
        prodvana.proto.prodvana.desired_state.manager_pb2.GetDesiredStateGraphResp,
    ]
    GetDesiredStateConvergenceSummary: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.desired_state.manager_pb2.GetDesiredStateConvergenceReq,
        prodvana.proto.prodvana.desired_state.manager_pb2.GetDesiredStateConvergenceSummaryResp,
    ]
    """Get the convergence summary for a desired state id.
    If the desired state id is pending, the returned summary will not have the entity_graph set but will have pending_set_desired_state set.
    The status will be set to PENDING_SET_DESIRED_STATE.
    If the desired state id was pending and failed to be set, the returned summary will not have the entity_graph set but will have pending_set_desired_state set.
    The status will be set to FAILED.
    """
    ValidateDesiredState: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.desired_state.manager_pb2.ValidateDesiredStateReq,
        prodvana.proto.prodvana.desired_state.manager_pb2.ValidateDesiredStateResp,
    ]
    SetManualApproval: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.desired_state.manager_pb2.SetManualApprovalReq,
        prodvana.proto.prodvana.desired_state.manager_pb2.SetManualApprovalResp,
    ]
    PromoteDelivery: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.desired_state.manager_pb2.PromoteDeliveryReq,
        prodvana.proto.prodvana.desired_state.manager_pb2.PromoteDeliveryResp,
    ]
    BypassProtection: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.desired_state.manager_pb2.BypassProtectionReq,
        prodvana.proto.prodvana.desired_state.manager_pb2.BypassProtectionResp,
    ]
    ListMaestroReleases: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.desired_state.manager_pb2.ListMaestroReleasesReq,
        prodvana.proto.prodvana.desired_state.manager_pb2.ListMaestroReleasesResp,
    ]
    GetMaestroRelease: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.desired_state.manager_pb2.GetMaestroReleaseReq,
        prodvana.proto.prodvana.desired_state.manager_pb2.GetMaestroReleaseResp,
    ]
    ListCombinedReleases: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.desired_state.manager_pb2.ListCombinedReleasesReq,
        prodvana.proto.prodvana.desired_state.manager_pb2.ListCombinedReleasesResp,
    ]
    """Get release history, where a release is either a Maestro Release or a Desired State from calling SetDesiredState"""
    ListServiceCombinedReleases: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.desired_state.manager_pb2.ListServiceCombinedReleasesReq,
        prodvana.proto.prodvana.desired_state.manager_pb2.ListCombinedReleasesResp,
    ]
    """Like ListCombinedReleases, but accepts an application/service names/ids instead of entity ID"""
    GetLatestCombinedReleaseDesiredState: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.desired_state.manager_pb2.GetLatestCombinedReleaseDesiredStateReq,
        prodvana.proto.prodvana.desired_state.manager_pb2.GetLatestCombinedReleaseDesiredStateResp,
    ]
    """get latest desired state that was set explicitly as part of a release, as defined by
    ListCombinedReleases. This is a shortcut for ListCombinedReleases(descending=True, page_size=1),
    then GetDesiredState or GetMaestroRelease depending on the type of release.
    """
    GetServiceLatestCombinedReleaseDesiredState: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.desired_state.manager_pb2.GetServiceLatestCombinedReleaseDesiredStateReq,
        prodvana.proto.prodvana.desired_state.manager_pb2.GetLatestCombinedReleaseDesiredStateResp,
    ]
    GetDebugState: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.desired_state.manager_pb2.GetDesiredStateReq,
        prodvana.proto.prodvana.desired_state.debug.debug_pb2.DumpState,
    ]

class DesiredStateManagerServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def SetDesiredState(
        self,
        request: prodvana.proto.prodvana.desired_state.manager_pb2.SetDesiredStateReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.desired_state.manager_pb2.SetDesiredStateResp: ...
    @abc.abstractmethod
    def PreviewEntityGraph(
        self,
        request: prodvana.proto.prodvana.desired_state.manager_pb2.SetDesiredStateReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.desired_state.manager_pb2.PreviewEntityGraphResp:
        """validate a SetDesiredState call and return a preview entity graph
        TODO(naphat) delete ValidateDesiredState and replace with this
        """
    @abc.abstractmethod
    def GetServiceDesiredStateConvergenceSummary(
        self,
        request: prodvana.proto.prodvana.desired_state.manager_pb2.GetServiceDesiredStateConvergenceSummaryReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.desired_state.manager_pb2.GetServiceDesiredStateConvergenceSummaryResp: ...
    @abc.abstractmethod
    def GetServiceLatestDesiredStateId(
        self,
        request: prodvana.proto.prodvana.desired_state.manager_pb2.GetServiceLatestDesiredStateIdReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.desired_state.manager_pb2.GetServiceLatestDesiredStateIdResp: ...
    @abc.abstractmethod
    def GetServiceDesiredStateIdHistory(
        self,
        request: prodvana.proto.prodvana.desired_state.manager_pb2.GetServiceDesiredStateIdHistoryReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.desired_state.manager_pb2.GetServiceDesiredStateIdHistoryResp: ...
    @abc.abstractmethod
    def GetServiceLastConvergedStates(
        self,
        request: prodvana.proto.prodvana.desired_state.manager_pb2.GetServiceLastConvergedStateReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.desired_state.manager_pb2.GetServiceLastConvergedStateResp: ...
    @abc.abstractmethod
    def GetServiceDesiredStateHistory(
        self,
        request: prodvana.proto.prodvana.desired_state.manager_pb2.GetServiceDesiredStateHistoryReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.desired_state.manager_pb2.GetServiceDesiredStateHistoryResp: ...
    @abc.abstractmethod
    def GetDesiredState(
        self,
        request: prodvana.proto.prodvana.desired_state.manager_pb2.GetDesiredStateReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.desired_state.manager_pb2.GetDesiredStateResp: ...
    @abc.abstractmethod
    def GetDesiredStateGraph(
        self,
        request: prodvana.proto.prodvana.desired_state.manager_pb2.GetDesiredStateGraphReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.desired_state.manager_pb2.GetDesiredStateGraphResp: ...
    @abc.abstractmethod
    def GetDesiredStateConvergenceSummary(
        self,
        request: prodvana.proto.prodvana.desired_state.manager_pb2.GetDesiredStateConvergenceReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.desired_state.manager_pb2.GetDesiredStateConvergenceSummaryResp:
        """Get the convergence summary for a desired state id.
        If the desired state id is pending, the returned summary will not have the entity_graph set but will have pending_set_desired_state set.
        The status will be set to PENDING_SET_DESIRED_STATE.
        If the desired state id was pending and failed to be set, the returned summary will not have the entity_graph set but will have pending_set_desired_state set.
        The status will be set to FAILED.
        """
    @abc.abstractmethod
    def ValidateDesiredState(
        self,
        request: prodvana.proto.prodvana.desired_state.manager_pb2.ValidateDesiredStateReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.desired_state.manager_pb2.ValidateDesiredStateResp: ...
    @abc.abstractmethod
    def SetManualApproval(
        self,
        request: prodvana.proto.prodvana.desired_state.manager_pb2.SetManualApprovalReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.desired_state.manager_pb2.SetManualApprovalResp: ...
    @abc.abstractmethod
    def PromoteDelivery(
        self,
        request: prodvana.proto.prodvana.desired_state.manager_pb2.PromoteDeliveryReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.desired_state.manager_pb2.PromoteDeliveryResp: ...
    @abc.abstractmethod
    def BypassProtection(
        self,
        request: prodvana.proto.prodvana.desired_state.manager_pb2.BypassProtectionReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.desired_state.manager_pb2.BypassProtectionResp: ...
    @abc.abstractmethod
    def ListMaestroReleases(
        self,
        request: prodvana.proto.prodvana.desired_state.manager_pb2.ListMaestroReleasesReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.desired_state.manager_pb2.ListMaestroReleasesResp: ...
    @abc.abstractmethod
    def GetMaestroRelease(
        self,
        request: prodvana.proto.prodvana.desired_state.manager_pb2.GetMaestroReleaseReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.desired_state.manager_pb2.GetMaestroReleaseResp: ...
    @abc.abstractmethod
    def ListCombinedReleases(
        self,
        request: prodvana.proto.prodvana.desired_state.manager_pb2.ListCombinedReleasesReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.desired_state.manager_pb2.ListCombinedReleasesResp:
        """Get release history, where a release is either a Maestro Release or a Desired State from calling SetDesiredState"""
    @abc.abstractmethod
    def ListServiceCombinedReleases(
        self,
        request: prodvana.proto.prodvana.desired_state.manager_pb2.ListServiceCombinedReleasesReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.desired_state.manager_pb2.ListCombinedReleasesResp:
        """Like ListCombinedReleases, but accepts an application/service names/ids instead of entity ID"""
    @abc.abstractmethod
    def GetLatestCombinedReleaseDesiredState(
        self,
        request: prodvana.proto.prodvana.desired_state.manager_pb2.GetLatestCombinedReleaseDesiredStateReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.desired_state.manager_pb2.GetLatestCombinedReleaseDesiredStateResp:
        """get latest desired state that was set explicitly as part of a release, as defined by
        ListCombinedReleases. This is a shortcut for ListCombinedReleases(descending=True, page_size=1),
        then GetDesiredState or GetMaestroRelease depending on the type of release.
        """
    @abc.abstractmethod
    def GetServiceLatestCombinedReleaseDesiredState(
        self,
        request: prodvana.proto.prodvana.desired_state.manager_pb2.GetServiceLatestCombinedReleaseDesiredStateReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.desired_state.manager_pb2.GetLatestCombinedReleaseDesiredStateResp: ...
    @abc.abstractmethod
    def GetDebugState(
        self,
        request: prodvana.proto.prodvana.desired_state.manager_pb2.GetDesiredStateReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.desired_state.debug.debug_pb2.DumpState: ...

def add_DesiredStateManagerServicer_to_server(servicer: DesiredStateManagerServicer, server: grpc.Server) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import collections.abc
import grpc
import prodvana.proto.prodvana.auth.auth_manager_pb2

class AuthManagerStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    GetAuthToken: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.auth.auth_manager_pb2.GetTokenRequest,
        prodvana.proto.prodvana.auth.auth_manager_pb2.GetAuthTokenResp,
    ]
    """web auth flow
    TODO(naphat) we should make this only available to our UI app
    """
    GetAuthUrl: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.auth.auth_manager_pb2.GetAuthUrlRequest,
        prodvana.proto.prodvana.auth.auth_manager_pb2.GetAuthUrlResponse,
    ]
    RefreshToken: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.auth.auth_manager_pb2.RefreshTokenReq,
        prodvana.proto.prodvana.auth.auth_manager_pb2.GetAuthTokenResp,
    ]
    CliAuth: grpc.UnaryStreamMultiCallable[
        prodvana.proto.prodvana.auth.auth_manager_pb2.CliAuthReq,
        prodvana.proto.prodvana.auth.auth_manager_pb2.CliAuthResp,
    ]
    """cli auth flow
    This returns a streaming response with exactly two items:
    1. Immediately, a UserPrmopt will be returned which should then be conveyed to the user
    2. Once user authenticates via a browser, a Token will be returned
    """

class AuthManagerServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def GetAuthToken(
        self,
        request: prodvana.proto.prodvana.auth.auth_manager_pb2.GetTokenRequest,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.auth.auth_manager_pb2.GetAuthTokenResp:
        """web auth flow
        TODO(naphat) we should make this only available to our UI app
        """
    @abc.abstractmethod
    def GetAuthUrl(
        self,
        request: prodvana.proto.prodvana.auth.auth_manager_pb2.GetAuthUrlRequest,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.auth.auth_manager_pb2.GetAuthUrlResponse: ...
    @abc.abstractmethod
    def RefreshToken(
        self,
        request: prodvana.proto.prodvana.auth.auth_manager_pb2.RefreshTokenReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.auth.auth_manager_pb2.GetAuthTokenResp: ...
    @abc.abstractmethod
    def CliAuth(
        self,
        request: prodvana.proto.prodvana.auth.auth_manager_pb2.CliAuthReq,
        context: grpc.ServicerContext,
    ) -> collections.abc.Iterator[prodvana.proto.prodvana.auth.auth_manager_pb2.CliAuthResp]:
        """cli auth flow
        This returns a streaming response with exactly two items:
        1. Immediately, a UserPrmopt will be returned which should then be conveyed to the user
        2. Once user authenticates via a browser, a Token will be returned
        """

def add_AuthManagerServicer_to_server(servicer: AuthManagerServicer, server: grpc.Server) -> None: ...

class AuthSessionManagerStub:
    """unlike AuthManager, AuthSessionManager is about the current authenticated session, i.e. it requires
    user to be authed already
    """

    def __init__(self, channel: grpc.Channel) -> None: ...
    Check: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.auth.auth_manager_pb2.Empty,
        prodvana.proto.prodvana.auth.auth_manager_pb2.Empty,
    ]
    """check if user is authenticated and token is still valid"""
    Logout: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.auth.auth_manager_pb2.LogoutReq,
        prodvana.proto.prodvana.auth.auth_manager_pb2.LogoutResp,
    ]

class AuthSessionManagerServicer(metaclass=abc.ABCMeta):
    """unlike AuthManager, AuthSessionManager is about the current authenticated session, i.e. it requires
    user to be authed already
    """

    @abc.abstractmethod
    def Check(
        self,
        request: prodvana.proto.prodvana.auth.auth_manager_pb2.Empty,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.auth.auth_manager_pb2.Empty:
        """check if user is authenticated and token is still valid"""
    @abc.abstractmethod
    def Logout(
        self,
        request: prodvana.proto.prodvana.auth.auth_manager_pb2.LogoutReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.auth.auth_manager_pb2.LogoutResp: ...

def add_AuthSessionManagerServicer_to_server(servicer: AuthSessionManagerServicer, server: grpc.Server) -> None: ...

class ApiTokenManagerStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    CreateOrgApiToken: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.auth.auth_manager_pb2.Empty,
        prodvana.proto.prodvana.auth.auth_manager_pb2.CreateOrgApiTokenResp,
    ]
    """Create an api token tied to the organization. This api token is not tied to the user in anyway,
    e.g. if the user is deleted, the token will continue to have access to the organization.
    This token currently does not expire, so be very careful with storing them.
    """
    CreateOrgApiToken2: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.auth.auth_manager_pb2.CreateOrgApiTokenReq,
        prodvana.proto.prodvana.auth.auth_manager_pb2.CreateOrgApiTokenResp,
    ]
    DeleteOrgApiToken: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.auth.auth_manager_pb2.DeleteOrgApiTokenReq,
        prodvana.proto.prodvana.auth.auth_manager_pb2.DeleteOrgApiTokenResp,
    ]
    ListOrgApiTokens: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.auth.auth_manager_pb2.ListOrgApiTokensReq,
        prodvana.proto.prodvana.auth.auth_manager_pb2.ListOrgApiTokensResp,
    ]

class ApiTokenManagerServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def CreateOrgApiToken(
        self,
        request: prodvana.proto.prodvana.auth.auth_manager_pb2.Empty,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.auth.auth_manager_pb2.CreateOrgApiTokenResp:
        """Create an api token tied to the organization. This api token is not tied to the user in anyway,
        e.g. if the user is deleted, the token will continue to have access to the organization.
        This token currently does not expire, so be very careful with storing them.
        """
    @abc.abstractmethod
    def CreateOrgApiToken2(
        self,
        request: prodvana.proto.prodvana.auth.auth_manager_pb2.CreateOrgApiTokenReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.auth.auth_manager_pb2.CreateOrgApiTokenResp: ...
    @abc.abstractmethod
    def DeleteOrgApiToken(
        self,
        request: prodvana.proto.prodvana.auth.auth_manager_pb2.DeleteOrgApiTokenReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.auth.auth_manager_pb2.DeleteOrgApiTokenResp: ...
    @abc.abstractmethod
    def ListOrgApiTokens(
        self,
        request: prodvana.proto.prodvana.auth.auth_manager_pb2.ListOrgApiTokensReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.auth.auth_manager_pb2.ListOrgApiTokensResp: ...

def add_ApiTokenManagerServicer_to_server(servicer: ApiTokenManagerServicer, server: grpc.Server) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class Constant(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    STRING_FIELD_NUMBER: builtins.int
    name: builtins.str
    """constant name, used in substitutions"""
    @property
    def string(self) -> global___StringConstant: ...
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        string: global___StringConstant | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["config_oneof", b"config_oneof", "string", b"string"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["config_oneof", b"config_oneof", "name", b"name", "string", b"string"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["config_oneof", b"config_oneof"]) -> typing_extensions.Literal["string"] | None: ...

global___Constant = Constant

class StringConstant(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VALUE_FIELD_NUMBER: builtins.int
    value: builtins.str
    def __init__(
        self,
        *,
        value: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["value", b"value"]) -> None: ...

global___StringConstant = StringConstant
